Update to simh 2.10-1; interdata and sds simulators are not included.

This commit is contained in:
fgsch 2002-11-28 16:41:11 +00:00
parent c305be8657
commit f96d098ccb
7 changed files with 34 additions and 212 deletions

View File

@ -1,12 +1,12 @@
# $OpenBSD: Makefile,v 1.30 2002/10/29 23:55:01 fgsch Exp $
# $OpenBSD: Makefile,v 1.31 2002/11/28 16:41:11 fgsch Exp $
# $NetBSD: Makefile,v 1.2 1998/08/23 20:48:03 frueauf Exp $
COMMENT= "PDP, IBM 1401, Nova and other CPUs simulator"
DISTNAME= simh-2.10b3
DISTNAME= simh-2.10-1
CATEGORIES= emulators
MASTER_SITES= http://simh.trailing-edge.com/sources/
DISTFILES= simhv210-0b3.zip xq_beta5.zip
DISTFILES= simhv210-1.zip
HOMEPAGE= http://simh.trailing-edge.com/
@ -20,7 +20,7 @@ WRKDIST= ${WRKDIR}
UNZIP= unzip -a -o
COPTS= -DUSE_SOCKLEN_T
MAKE_FILE= makefile
MAKE_FILE= makefile_ether
.if ${MACHINE_ARCH} == "alpha" || ${MACHINE_ARCH} == "sparc64"
COPTS+= -O0
@ -35,14 +35,13 @@ VMEM_WARNING= Yes
pre-build:
@mkdir ${WRKBUILD}/BIN
@cp ${WRKDIST}/AltairZ80/altairZ80_defs.h \
${WRKDIR}/AltairZ80/altairz80_defs.h
# @cp ${WRKDIST}/AltairZ80/altairZ80_defs.h \
# ${WRKDIR}/AltairZ80/altairz80_defs.h
do-install:
.for f in ${SIMS}
${INSTALL_PROGRAM} ${WRKBUILD}/BIN/${f} ${PREFIX}/bin/simh-${f}
.endfor
${INSTALL_DATA_DIR} ${PREFIX}/lib/simh
${INSTALL_DATA_DIR} ${PREFIX}/lib/simh/vax
${INSTALL_DATA} ${WRKDIST}/VAX/ka655.bin ${PREFIX}/lib/simh/vax
${INSTALL_DATA_DIR} ${PREFIX}/share/doc/simh

View File

@ -1,6 +1,3 @@
MD5 (simhv210-0b3.zip) = 3a6921500d568b1aafb88eb93543eaa7
MD5 (xq_beta5.zip) = 9c37e401e946dcad27d88107f7e5c94d
RMD160 (simhv210-0b3.zip) = f6fcf736c78c3b6e404f5824fbd28f805cf8e9aa
RMD160 (xq_beta5.zip) = c3b15245530d6f96d4106e940e32ac53aa2302e2
SHA1 (simhv210-0b3.zip) = 6e6347dc391fe2a4b5a49b8b92f3986384c3837e
SHA1 (xq_beta5.zip) = a66fe7fecb76737632e262ae40c3d59147071a7e
MD5 (simhv210-1.zip) = 10abbd6066dd0790cf58ec8bf9d049af
RMD160 (simhv210-1.zip) = 99249dba9cca665d888c345806fc5bd0776656f8
SHA1 (simhv210-1.zip) = 579a95cd611c67722a6cc0ab0febb7d9ec4fbc78

View File

@ -1,77 +0,0 @@
$OpenBSD: patch-PDP11_pdp11_xq_c,v 1.1 2002/10/29 23:55:01 fgsch Exp $
--- PDP11/pdp11_xq.c.orig Tue Oct 22 08:50:40 2002
+++ PDP11/pdp11_xq.c Fri Oct 25 16:12:39 2002
@@ -180,7 +180,7 @@ MTAB xq_mod[] = {
};
DEVICE xq_dev = {
- "XQ", &xq_unit, xq_reg, xq_mod,
+ "XQ", (struct unit *)&xq_unit, xq_reg, xq_mod,
2, XQ_RDX, 0, 1, XQ_RDX, 8,
&xq_ex, &xq_dep, &xq_reset,
NULL, &xq_attach, &xq_detach,
@@ -623,8 +623,8 @@ t_stat xq_process_mop(void)
t_addr address;
uint16 size;
int32 wstatus;
- struct xq_meb* meb = &xq.write_buffer.msg[0200];
- const struct xq_meb* limit = &xq.write_buffer.msg[0400];
+ struct xq_meb* meb = (struct xq_meb *)&xq.write_buffer.msg[0200];
+ const struct xq_meb* limit = (struct xq_meb *)&xq.write_buffer.msg[0400];
if (xq.type == XQ_T_DEQNA) /* DEQNA's don't MOP */
return SCPE_NOFNC;
@@ -642,7 +642,7 @@ t_stat xq_process_mop(void)
case 0: /* MOP Termination */
break;
case 1: /* MOP Read Ethernet Address */
- wstatus = Map_WriteB(address, sizeof(ETH_MAC), &xq.setup.macs[0], NOMAP);
+ wstatus = Map_WriteB(address, sizeof(ETH_MAC), (uint8 *)&xq.setup.macs[0], NOMAP);
if (wstatus) return xq_nxm_error();
break;
case 2: /* MOP Reset System ID */
@@ -823,7 +823,7 @@ t_stat xq_process_xbdl()
}
/* update write status */
- wstatus = Map_WriteW(xq.xbdl_ba + 8, 4, write_success, NOMAP);
+ wstatus = Map_WriteW(xq.xbdl_ba + 8, 4, (uint16 *)write_success, NOMAP);
if (wstatus) return xq_nxm_error();
/* clear write buffer */
@@ -850,7 +850,7 @@ t_stat xq_process_xbdl()
} else { /* not at end-of-message */
/* update bdl status words */
- wstatus = Map_WriteW(xq.xbdl_ba + 8, 4, implicit_chain_status, NOMAP);
+ wstatus = Map_WriteW(xq.xbdl_ba + 8, 4, (uint16 *)implicit_chain_status, NOMAP);
if(wstatus) return xq_nxm_error();
}
@@ -946,7 +946,7 @@ void xq_sw_reset(void)
xq_cancel_santmr();
/* disconnect ethernet reception */
- sim_cancel(&xq_unit);
+ sim_cancel(&xq_unit[0]);
/* reset csr bits */
xq.csr = XQ_CSR_XL | XQ_CSR_RL;
@@ -1017,7 +1017,7 @@ t_stat xq_wr_csr(int32 data)
/* start receiver when RE transitions to set */
if (~saved_csr & XQ_CSR_RE & data) {
//xq_start_receiver();
- sim_activate(&xq_unit, xq.rtime);
+ sim_activate(&xq_unit[0], xq.rtime);
}
return SCPE_OK;
@@ -1192,7 +1192,7 @@ t_stat xq_svc(UNIT* uptr)
/* resubmit if still receive enabled */
if (xq.csr & XQ_CSR_RE)
- sim_activate(&xq_unit, xq.rtime);
+ sim_activate(&xq_unit[0], xq.rtime);
return SCPE_OK;
}

View File

@ -1,6 +1,6 @@
$OpenBSD: patch-makefile,v 1.3 2002/10/29 23:55:01 fgsch Exp $
--- makefile.orig Sat Oct 26 08:09:58 2002
+++ makefile Tue Oct 29 20:00:44 2002
$OpenBSD: patch-makefile_ether,v 1.1 2002/11/28 16:41:12 fgsch Exp $
--- makefile_ether.orig Tue Nov 12 20:30:02 2002
+++ makefile_ether Thu Nov 28 13:23:12 2002
@@ -3,8 +3,9 @@
# Note: -O2 is sometimes broken in GCC when setjump/longjump is being
# used. Try -O2 only with released simulators.
@ -12,23 +12,16 @@ $OpenBSD: patch-makefile,v 1.3 2002/10/29 23:55:01 fgsch Exp $
@@ -62,7 +63,7 @@ PDP11 = ${PDP11D}pdp11_fp.c ${PDP11D}pdp
${PDP11D}pdp11_tm.c ${PDP11D}pdp11_ts.c ${PDP11D}pdp11_io.c \
${PDP11D}pdp11_rq.c ${PDP11D}pdp11_tq.c ${PDP11D}pdp11_pclk.c \
${PDP11D}pdp11_ry.c ${PDP11D}pdp11_pt.c ${PDP11D}pdp11_hk.c \
- ${PDP11D}pdp11_xq.c
+ ${PDP11D}pdp11_xq.c sim_ether.c
PDP11_OPT = -I ${PDP11D}
@@ -199,8 +200,8 @@ SDS_OPT = -I ${SDSD}
all : ${BIN}pdp1 ${BIN}pdp4 ${BIN}pdp7 ${BIN}pdp8 ${BIN}pdp9 ${BIN}pdp15 \
${BIN}pdp11 ${BIN}pdp10 ${BIN}vax ${BIN}nova ${BIN}eclipse ${BIN}h316 \
${BIN}hp2100 ${BIN}i1401 ${BIN}i1620 ${BIN}s3 ${BIN}altair \
- ${BIN}altairz80 ${BIN}gri ${BIN}i1620 ${BIN}ibm1130 \
- ${BIN}id16 ${BIN}id32 ${BIN}sds
+ ${BIN}altairz80 ${BIN}gri ${BIN}i1620 ${BIN}ibm1130
+# ${BIN}id16 ${BIN}id32 ${BIN}sds
@@ -73,7 +74,7 @@ VAX = ${VAXD}vax_cpu1.c ${VAXD}vax_cpu.c
${VAXD}vax_sysdev.c \
${PDP11D}pdp11_rl.c ${PDP11D}pdp11_rq.c ${PDP11D}pdp11_ts.c \
${PDP11D}pdp11_dz.c ${PDP11D}pdp11_lp.c ${PDP11D}pdp11_tq.c \
- ${PDP11D}pdp11_pt.c ${PDP11D}pdp11_xq.c
+ ${PDP11D}pdp11_pt.c ${PDP11D}pdp11_xq.c sim_ether.c
VAX_OPT = -I ${VAXD} -I ${PDP11D} -DUSE_INT64
@@ -208,106 +209,106 @@ all : ${BIN}pdp1 ${BIN}pdp4 ${BIN}pdp7 $
# Individual builds
@ -77,13 +70,13 @@ $OpenBSD: patch-makefile,v 1.3 2002/10/29 23:55:01 fgsch Exp $
${BIN}pdp11 : ${PDP11} ${SIM}
- ${CC} ${PDP11} ${SIM} ${PDP11_OPT} -o $@
+ ${CC} ${CFLAGS} ${PDP11} ${SIM} ${PDP11_OPT} -o $@ -lpcap
+ ${CC} ${CFLAGS} ${PDP11} ${SIM} ${PDP11_OPT} -o $@
${BIN}vax : ${VAX} ${SIM}
- ${CC} ${VAX} ${SIM} ${VAX_OPT} -o $@
+ ${CC} ${CFLAGS} ${VAX} ${SIM} ${VAX_OPT} -o $@ -lpcap
+ ${CC} ${CFLAGS} ${VAX} ${SIM} ${VAX_OPT} -o $@

View File

@ -1,87 +0,0 @@
$OpenBSD: patch-sim_ether_c,v 1.1 2002/10/29 23:55:01 fgsch Exp $
--- sim_ether.c.orig Fri Oct 25 16:27:11 2002
+++ sim_ether.c Fri Oct 25 16:30:31 2002
@@ -99,7 +99,8 @@ void eth_zero(ETH_DEV* dev)
/* Non-implemented versions */
/*============================================================================*/
-#if !defined (WIN32) && !defined(linux) && !defined(__NetBSD__)
+#if !defined (WIN32) && !defined(linux) && !defined(__NetBSD__) && \
+ !defined(__OpenBSD__)
t_stat eth_open (ETH_DEV* dev, char* name)
{return SCPE_NOFNC;}
t_stat eth_close (ETH_DEV* dev)
@@ -116,20 +117,21 @@ int eth_devices (int max, ETH_LIST* dev)
#else /* endif unimplemented */
/*============================================================================*/
/* Win32, Linux, and NetBSD routines - Uses WinPCAP and libpcap packages */
/*============================================================================*/
#include <pcap.h>
#ifdef WIN32
#include <packet32.h>
#endif /*WIN32*/
-#ifdef __NetBSD__
+#if defined(__NetBSD__) || defined(__OpenBSD__)
#include <sys/ioctl.h>
#include <net/bpf.h>
-#endif /* __NetBSD__ */
-#if defined(linux) || defined(__NetBSD__)
+#endif /* __NetBSD__ || __OpenBSD__ */
+#if defined(linux) || defined(__NetBSD__) || defined(__OpenBSD__)
#include <fcntl.h>
-#endif /*linux || __NetBSD__*/
+#endif /*linux || __NetBSD__ || __OpenBSD__*/
t_stat eth_open(ETH_DEV* dev, char* name)
{
@@ -166,17 +168,17 @@ t_stat eth_open(ETH_DEV* dev, char* name
dev->name = malloc(strlen(savname)+1);
strcpy(dev->name, savname);
-#ifdef __NetBSD__
+#if defined(__NetBSD__) || defined(__OpenBSD__)
/* tell the kernel that the header is fully-formed when it gets it.
this is required in order to fake the src address. */
i = 1;
ioctl(pcap_fileno(dev->handle), BIOCSHDRCMPLT, &i);
-#endif /* __NetBSD__ */
+#endif /* __NetBSD__ || __OpenBSD__ */
-#if defined(linux) || defined(__NetBSD__)
+#if defined(linux) || defined(__NetBSD__) || defined(__OpenBSD__)
/* set file non-blocking */
fcntl(pcap_fileno(dev->handle), F_SETFL, fcntl(pcap_fileno(dev->handle), F_GETFL, 0) | O_NONBLOCK);
-#endif /*linux || __NetBSD__*/
+#endif /*linux || __NetBSD__ || __OpenBSD__*/
return SCPE_OK;
}
@@ -364,7 +366,7 @@ int eth_devices(int max, ETH_LIST* list)
return index; /* count of devices */
}
-#endif /* Win32 || linux || __NetBSD__ */
+#endif /* Win32 || linux || __NetBSD__ || __OpenBSD__ */
/*============================================================================*/
/* linux-specific code */
@@ -422,7 +424,7 @@ int PacketGetAdapterNames(char* buffer,
/* NetBSD-specific code */
/*============================================================================*/
-#ifdef __NetBSD__
+#if defined(__NetBSD__) || defined(__OpenBSD__)
#include <sys/types.h>
#include <sys/socket.h>
#include <net/if_dl.h>
@@ -470,5 +472,5 @@ int PacketGetAdapterNames(char* buffer,
return (ptr);
}
-#endif /* __NetBSD__ */
+#endif /* __NetBSD__ || __OpenBSD__ */

View File

@ -8,16 +8,15 @@ and to publish them as freeware on the Internet, with freely available
copies of significant or representative software.
Simulators included in this package:
- Data Central Nova
- Data Central Eclipse
- Digital Equipment Corporation PDP-1, PDP-4, PDP-8, PDP-9, PDP-10,
PDP-11, PDP-15
- Digital Equipment Corporation VAX
- IBM 1401
- IBM System 3
- Hewlett Packard HP 2100
- Data Central Nova, Eclipse
- Digital Equipment Corporation PDP-1, PDP-4, PDP-7, PDP-8, PDP-9,
PDP-10, PDP-11, PDP-15, VAX
- GRI Corporation GRI-909
- IBM 1401, 1620, 1130, System 3
- Interdata (perkin-Elmer) 16b and 32b systems
- Hewlett Packard HP 2116, 2100, 21MX
- Honeywell H316
- MITS Altair 8800
- MITS Altair Z80
- MITS Altair 8800, with both 8080 and Z80
- Scientific Data Systems SDS 940
WWW: ${HOMEPAGE}

View File

@ -1,4 +1,4 @@
@comment $OpenBSD: PLIST,v 1.10 2002/10/29 23:55:01 fgsch Exp $
@comment $OpenBSD: PLIST,v 1.11 2002/11/28 16:41:12 fgsch Exp $
bin/simh-altair
bin/simh-altairz80
bin/simh-eclipse
@ -17,7 +17,8 @@ bin/simh-pdp9
bin/simh-s3
bin/simh-vax
lib/simh/vax/ka655.bin
share/doc/simh/0readme210.txt
share/doc/simh/0readme_210.txt
share/doc/simh/0readme_ethernet.txt
share/doc/simh/altair.txt
share/doc/simh/altairz80.txt
share/doc/simh/eclipse.txt
@ -28,7 +29,6 @@ share/doc/simh/hp2100_diag.txt
share/doc/simh/hp2100_doc.txt
share/doc/simh/i1401_doc.txt
share/doc/simh/i1620_doc.txt
share/doc/simh/id_doc.txt
share/doc/simh/nova_doc.txt
share/doc/simh/pdp10_doc.txt
share/doc/simh/pdp11_doc.txt
@ -38,12 +38,10 @@ share/doc/simh/pdp8_doc.txt
share/doc/simh/readme1130.txt
share/doc/simh/readme_s3.txt
share/doc/simh/readme_update.txt
share/doc/simh/sds_doc.txt
share/doc/simh/simh_doc.txt
share/doc/simh/simh_swre.txt
share/doc/simh/system3.txt
share/doc/simh/vax_doc.txt
share/doc/simh/xq_README.txt
@dirrm share/doc/simh
@dirrm lib/simh/vax
@dirrm lib/simh
@@ -116,20 +117,21 @@ int eth_devices (int max, ETH_LIST* dev)
#else /* endif unimplemented */
/*============================================================================*/
-/* Win32, Linux, and NetBSD routines - Uses WinPCAP and libpcap packages */
+/* Win32, Linux, NetBSD and OpenSBD routines - Uses WinPCAP and libpcap */
+/* packages */
/*============================================================================*/
#include <pcap.h>